@@ -466,16 +466,19 @@ export default class ComplianceModel {
 
   async getPlacementRulesFromParent(parent = {}) {
     const placements = _.get(parent, 'status.placement', []);
-    const response = await this.kubeConnector.getResources(
-      (ns) => `${appAPIPrefix}/${ns}/placementrules`,
-      { kind: 'PlacementRule', namespaces: [parent.namespace] },
-    );
     const map = new Map();
-    if (response) {
-      response.forEach((item) => map.set(item.metadata.name, item));
-    }
     const placementPolicies = [];
-
+    if (parent.namespace) {
+      const response = await this.kubeConnector.getResources(
+        (ns) => `${appAPIPrefix}/${ns}/placementrules`,
+        { kind: 'PlacementRule', namespaces: [parent.namespace] },
+      );
+      if (response) {
+        response.forEach((item) => map.set(item.metadata.name, item));
+      }
+    } else {
+      logger.debug('Parent policy does not contain a namespace to get placementRules from:', parent);
+    }
     placements.forEach((placement) => {
       const rule = _.get(placement, 'placementRule', '');
       const pp = map.get(rule);
@@ -485,8 +488,6 @@ export default class ComplianceModel {
           clusterLabels: spec.clusterSelector,
           metadata: pp.metadata,
           raw: pp,
-          clusterReplicas: spec.clusterReplicas,
-          resourceSelector: spec.resourceHint,
           status: pp.status,
         });
       }
@@ -496,15 +497,19 @@ export default class ComplianceModel {
 
   async getPlacementBindingsFromParent(parent = {}) {
     const placements = _.get(parent, 'status.placement', []);
-    const response = await this.kubeConnector.getResources(
-      (ns) => `${policyAPIPrefix}/${ns}/placementbindings`,
-      { kind: 'PlacementBinding', namespaces: [parent.namespace] },
-    );
     const map = new Map();
-    if (response) {
-      response.forEach((item) => map.set(item.metadata.name, item));
-    }
     const placementBindings = [];
+    if (parent.namespace) {
+      const response = await this.kubeConnector.getResources(
+        (ns) => `${policyAPIPrefix}/${ns}/placementbindings`,
+        { kind: 'PlacementBinding', namespaces: [parent.namespace] },
+      );
+      if (response) {
+        response.forEach((item) => map.set(item.metadata.name, item));
+      }
+    } else {
+      logger.debug('Parent policy does not contain a namespace to get placementBindings from:', parent);
+    }
 
     placements.forEach((placement) => {
       const binding = _.get(placement, 'placementBinding', '');
@@ -540,8 +545,6 @@ export default class ComplianceModel {
           clusterLabels: spec.clusterSelector,
           metadata: pp.metadata,
           raw: pp,
-          clusterReplicas: spec.clusterReplicas,
-          resourceSelector: spec.resourceHint,
           status: pp.status,
         });
       }
@@ -702,52 +705,6 @@ export default class ComplianceModel {
     return allClustersInPolicyResult;
   }
 
-  // input is a list of policies name with each clusterName specified
-  async getAllPoliciesInApplication(violatedPolicies) {
-    const filterViolatedPolicies = [];
-    if (Array.isArray(violatedPolicies) && violatedPolicies.length > 0) {
-      const clusterSet = new Set();
-      // use policy name + cluster name as combination set value
-      const violatedPoliciesSet = new Set();
-      violatedPolicies.forEach((policy) => {
-        if (policy.name && Array.isArray(policy.clusters) && policy.clusters.length > 0) {
-          policy.clusters.forEach((cluster) => {
-            if (cluster.name) {
-              const clusterKey = cluster.name;
-              if (!clusterSet.has(clusterKey)) {
-                clusterSet.add(clusterKey);
-              }
-              const violatedPoliciesKey = `${policy.name}+${cluster.name}`;
-              if (!violatedPoliciesSet.has(violatedPoliciesKey)) {
-                violatedPoliciesSet.add(violatedPoliciesKey);
-              }
-            }
-          });
-        }
-      });
-
-      const outerPromises = Array.from(clusterSet).map(async (clusterName) => {
-        const allPoliciesInCluster = await this.getAllPoliciesInCluster(clusterName);
-        const innerPromises = allPoliciesInCluster.map(async (policy) => {
-          if (policy.metadata) {
-            const policiesKey = `${_.get(policy, 'metadata.labels.parent-policy', '')}+${clusterName}`;
-            const realNameKey = `${_.get(policy, metadataNameStr, '')}+${clusterName}`;
-            if (violatedPoliciesSet.has(policiesKey) || violatedPoliciesSet.has(realNameKey)) {
-              const filterViolatedPolicy = policy;
-              filterViolatedPolicy.cluster = clusterName;
-              await filterViolatedPolicies.push(filterViolatedPolicy);
-            }
-          }
-        });
-        // here need to await all inner loop async calls completed
-        await Promise.all(innerPromises);
-      });
-      // here need to await all outer loop async calls completed
-      await Promise.all(outerPromises);
-    }
-    return filterViolatedPolicies;
-  }
-
   async getPolicyFromClusterNS(allClusterNS, hubNamespace, policyName) {
     const promises = allClusterNS.map(async (ns) => {
       const URL = `${policyAPIPrefix}/${ns}/policies/${hubNamespace}.${policyName}`;
